#!/bin/sh

argc=$#
if [ $argc -eq 0 -o "$1" == "--help" -o "$1" == "-h" ]; then
   name=`basename $0`
   cat << EOF
Usage: ${name} [ options ] [ file1 [ file2 ... ] ]
   remove the files UNLESS --no-kill is given.

   -n|--no-croak   	dont exit if a file in this list does not exist
   -p N                 use patch level N (strip N leading directories)
   -nr|--no-rm-dirs    do not "rm -Rf" directories , default behavoir 
		is to remove dirs
   -nk|--no-kill   	empty the files listed, putting the string 
		specified in them

   to remove a directory recursively use 
      dir:path/to/dir
   or
      leave a trailing / on the file: ie some/directory/

   Example:
      ${name} badfiles.txt

   badfiles.txt:
BUG="3423"
FILES="
file1
file2
directory/
"
         will put "#/* bugID:1234 remove files */" in all files listed
         in badfiles.txt
EOF
   exit 2
fi

doExit() {
   exit $1
}

name=`basename $0`
allow_missing=0
list=""
patchlevel=0
pretend=${PRETEND:-0}
rm_dirs=1
killemall=1

while [ "$1" != "" ]; do
   case $1 in
      -n|--no-croak)
         shift;
         allow_missing=1;
         ;;
      -p*)
         if [ "${1#-p}" != "" ]; then
            patchlevel=${1#-p}
         else
            patchlevel=${2}
            shift
         fi
         [ "${patchlevel#*[^0-9]}" != "${patchlevel}" ] && {
            echo "patchlevel ${patchlevel} is not a number";
            doExit 1
         }
         shift;
         ;;
      -nr|--no-rm-dirs)
         shift;
         rm_dirs=0;
         ;;
      -nk|--no-kill)
         shift;
         killemall=0;
         ;;
      *)
         [ ! -e ${1} ] && { echo "no file ${1}"; doExit 1; }
         list="${list} ${1}"
         shift;
         ;;
   esac
done
list=${list# }

[ -z "${list}" ] && { echo "no files given"; doExit 1; }

CR="
"
OIFS=${IFS}

VARS="BUG FILES COMMENT"

for controlfile in ${list}
do
   unset ${VARS}
   source ${controlfile} || 
      { echo "failed to source ${controlfile}" ; doExit 1; }
   [ -z "${FILES}" ] && { echo "empty file list in ${controlfile}"; doExit 1; }
   [ -z "${BUG}" ] && { echo "no bug listed in ${controlfile}"; doExit 1; }

   echo "working on ${controlfile}:${BUG}"
   COMMENT=${COMMENT-"#/* bugID:${BUG} remove files */"}
   IFS=${CR}
   for file in ${FILES}
   do
      IFS=${OIFS}
      [ -z "${file}" -o "${file#\#}" != "${file}" ] && continue;

      dir=""
      [ "${file#dir:}" != "${file}" -o "${file%/}" != "${file}" ] && 
         { dir=${file#dir:} ; file=${file#dir:}; }

      n=0;
      ofile=${file}
      while [ $n -lt $patchlevel ]; do
         [ "${file#*/}" = "${file}" -o -z "${file#*/}" ] && { 
            echo "file ${ofile} doesnt work with patchlevel ${patchlevel}" ; 
            doExit 1; 
         }
         file=${file#*/}
         let n=n+1
      done

      if [ ! -e "${file}" ]; then
         if [ ${allow_missing} -eq 0 ]; then
            echo "no file ${file}"
            doExit 1
         else
            echo "Warning: ${file} not found"
         fi
      fi

      if [ ! -z "${dir}" ]; then
         [ ! -d "${file}" ] && {
            echo "directory given as dir:${file} is not a dir";
            doExit 1
         }
         if [ $rm_dirs -ne 0 ]; then
            echo "recursively removing ${dir}"
            if [ "${pretend}" = "0" ]; then
               rm -Rf ${dir} || 
                  { echo "failed to remove dir ${dir}"; doExit 1; }
            fi
         else
            IFS=${CR}
            for curfile in `find ${dir} -type f`; do
               IFS=${OIFS}
               echo "  emptying ${curfile}"
               if [ "${pretend}" = "0" ]; then
                  echo -E "${COMMENT}" > "${curfile}" ||
                     { echo "couldnt remove dir ${curfile}"; doExit 1; }
               fi
            done
            IFS=${OIFS}
         fi
      else
         if [ "${killemall}" = "1" ]; then
            echo "  killing ${file}"
            if [ "${pretend}" = "0" ]; then
               rm -f ${file}
            fi
         else
            echo -E "emptying ${file}"
            if [ "${pretend}" = "0" ]; then
               echo -E "${COMMENT}" > "${file}" || 
                  { echo "couldnt write ${string} to ${file}"; doExit 1; }
            fi
         fi
      fi
   done
   IFS=${OIFS}
done

IFS=${OIFS}

doExit 0
